      SUBROUTINE FSEEN2(NVSEEA,NVSEEB)
C
C The FSEEN2 subroutine calculates NSEENA and NSEENB, arrays of the
C fractions of vehicles seen by RSD in an annual or biennial IM
C program, respectively.  It uses a method that adjusts the
C by-vehicle-age theoretical results (assuming a Poisson distribution)
C by altering the overall average remote sensing sampling rate by
C the ratio of the VMT for the particular age over the VMT for the
C newest vehicle age.
C
C Called by subroutine R1
C
C Input:
C by user:  none
C common blocks:  OP1
C data file(s): none
C subroutine arguments: none
C
C Output:
C by screen:
C common blocks:
C data file(s):  none used
C subroutine arguments:  NVSEEA, NVSEEB
C
C Array subscripts:
C
C EFF(3)         - EFF(pollutant)
C EXCESS(3,15,3) - EXCESS(Tech type, cutpoint, pollutant)
C FACTRL(11)     - FACTRL(ISCAN)
C NVSEEA(24)     - NVSEEA(IBY)
C NVSEEB(24)     - NVSEEB(IBY)
C VMT(25)        - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -
C AGE     I   The age at which a car first becomes subject to the program
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C EXCESS  R   Array of user supplied RSD excess identified fractions
C              dependent upon Tech type, CO cut point, and pollutant,
C              used in Options 1 and 2
C FACTRL  R   Factorial look-up table containing in each element the
C              factorial of one less than the element's array index 
C FRACA   R   Fraction of vehicles in annual program that are seen a
C              chosen number of times or more; VMT adjusted Poisson
C              prediction
C FRACB   R   Fraction of vehicles in biennial program that are seen a
C              chosen number of times or more; VMT adjusted Poisson
C              prediction
C IBY     I   Counter for Benefit Year Age
C ISCAN   I   Counter for number of scans
C NUMBER  I   Total number of vehicles subject to the inspection program
C NVSEEA  R   New version of FVSEEN after taking into account VMT ratio
C              adjustment and age exemptions
C NVSEEB  R   New version of FVSEEN after taking into account VMT ratio
C              adjustment and age exemptions
C OPTION  I   Option number 1, 2, or 3--see RSDDRV
C RNUMBE  R   Real value of NUMBER
C RSCAN   R   Real value of SCAN
C RVMT1   R   Real value of VMT(1)
C SCAN    I   Times per month the RSD sites scanned valid vehicles.
C TIMES   I   Number of times a vehicle must be scanned to be eligible
C              for targetting
C VMT     I   Vehicle miles traveled, by age, per year
C
C
C Notes:
C         
C 07-Sept-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 20-Nov-1995 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      INTEGER AGE, IBY, ISCAN, NUMBER, OPTION, SCAN, TIMES, VMT(25)
C
      REAL CUTS(3), EFF(3), EXCESS(3,15,3), FACTRL(11), FRACA, FRACB
      REAL NVSEEA(24), NVSEEB(24), RVMT1
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C ------------------------------
C DATA STATEMENT INITIALIZATIONS
C ------------------------------
C
      DATA FACTRL/ 1., 1., 2., 6., 24., 120., 720., 5040., 40320., 
     &             362880., 3628800. /
C
C ----------------------------------------
C SET UP FRACTIONS OF NEWEST VEHICLES SEEN
C ----------------------------------------
C
C Set NUMBER, SCAN, and VMT(1) to real values
C
      RNUMBE=FLOAT(NUMBER)
      RSCAN=FLOAT(SCAN)
      RVMT1=FLOAT(VMT(1))
C
      DO 10 IBY=1,24
C
C Evaluate annual and biennial program fractions for every benefit
C year
C
C FRACA, the adjusted Poisson prediction for annual programs and
C FRACB, the adjusted Poisson prediction for biennial programs
C are found using the following:
C 1) average number of times a vehicle subject to the program is
C scanned by RSD (which is the total valid scans made at the RSD sites
C during the I/M period, which is two years for biennial programs,
C divided by the total number of vehicles in the program, SCAN divided
C by NUMBER; see Note below); and
C 2) number of valid scans a particular vehicle is required to have
C before it can be examined to determine if it should go to I/M;
C statistics provides an expression which can be used to find the
C predicted (assuming that cars were passing by the RSD in a completely
C random fashion, which is not actually the case) value for the fraction
C of the program cars scanned a chosen number of times.  Also, the  
C expression may be used (as it is here) to find the fraction scanned
C the chosen number of times or more.
C 3) the VMT ratio, which is VMT(IBY)/VMT(1), and is used to adjust the
C theoretical Poisson prediction toward fewer scans for older cars by
C being multiplied by the average scans factor wherever it appears.
C
C Set FRACA and FRACB to one.  These are the fractions of vehicles
C scanned zero or more times.
C
      FRACA=1.
      FRACB=1.
C
      DO 20 ISCAN=1,TIMES
C
C Subtract from the current values of FRACA and FRACB the fraction of
C vehicles scanned ISCAN-1 times.  The result is the fraction of
C vehicles scanned ISCAN or more times.  (FACTRL is an array containing
C factorial values of its indicies-less-one.)
C (Note:  intuitively, SCAN, the number of valid RSD scans per month
C  would be multiplied by 24 [months] to get the total number of valid
C  RSD scans over a two year biennial I/M program period, but EPA has
C  determined that 18 [months] provides a more accurate estimate of the
C  actual situation.)
C
        FRACA=FRACA-
     &        ( (RSCAN*12./RNUMBE*FLOAT(VMT(IBY))/RVMT1)**(ISCAN-1) )*
     &        ( EXP(-RSCAN*12./RNUMBE*FLOAT(VMT(IBY))/RVMT1) )/
     &        ( FACTRL(ISCAN) )
        FRACB=FRACB-
     &        ( (RSCAN*18./RNUMBE*FLOAT(VMT(IBY))/RVMT1)**(ISCAN-1) )*
     &        ( EXP(-RSCAN*18./RNUMBE*FLOAT(VMT(IBY))/RVMT1) )/
     &        ( FACTRL(ISCAN) )
 20   CONTINUE
C
C Take age exemptions into account.
C
        IF (IBY.LT.AGE) THEN
          NVSEEA(IBY)=0.
          NVSEEB(IBY)=0.
        ELSE
          NVSEEA(IBY)=FRACA
          NVSEEB(IBY)=FRACB
        END IF
C
 10   CONTINUE
C
      RETURN
      END
