      SUBROUTINE IM3(IN1981,IN198H,OUT198,NVSEEA,UEXCE4,NVSEEB,RSDD)
C
C IM3
C
C Calculates new sets of IM credits for
C IM programs using Remote Sensing Devices (RSD) 
C from the existing 1981 and newer model years vehicles credits
C
C Called by INPUT
C
C Calls no subroutines
C
C Input:
C by user:  none
C common block(s):  OP1
C data file(s):  files whose names are passed in IN1981 and IN198H  
C subroutine arguments:  IN1981, IN198H, OUT198, NVSEEA, UEXCE4, NVSEEB,
C                        RSDD
C
C Output:
C by screen:  none
C common blocks(s):  none
C data file(s):  file whose name is passed in OUT198
C subroutine arguments:  none
C
C Array subscripts:
C
C ACREDT(18,3,24) - ACREDT(IMY,IP,IBY)
C CUTS(3)         - CUTS(ITECH)
C EFF(3)          - EFF(IP)
C EXCESS(3,15,3)  - EXCESS(ITECH,cutpoint,IP)
C HACRDT(24)      - HACRDT(IBY)
C HBCRDT(24)      - HBCRDT(IBY)
C NCREDT(24)      - NCREDT(IBY)
C NVSEEA(25)      - NVSEEA(age of vehicle)
C NVSEEB(25)      - NVSEEB(age of vehicle)
C SMARK(4)        - SMARK(ISMART)
C SMART(4)        - SMART(ISMART)
C UEXCE4(3)       - UEXCE4(pollutant:  1=HC, 2=CO, & 3=NOx)
C VMT(25)         - VMT(IBY)
C
C Variable dictionary:
C
C  Name  Type Description
C ------  -   -- -  -   -    -     -      -       -        -         -  
C ACREDT  R   Array of annual credits read from the input file
C AGE     I   Age at which a veh. first becomes subject to RSD program
C CCUTCO  R   CO cut point read from an input file annual Smart line
C CCUTHC  R   HC cut point read from an input file annual Smart line
C CCUTNO  R   NOx cut point read from an input file annual Smart line
C CKUTCO  R   CO cut point read from an input file biennial Smart line
C CKUTHC  R   HC cut point read from an input file biennial Smart line
C CKUTNO  R   NOx cut point read from an input file biennial Smart line
C CRDCOM  C   Char. string of comments from the end of a credit line 
C CUTS    R   Array of RSD CO cutpoints by Tech type:  1, 2, 4+
C EFF     R   Array for the three pollutants (1=HC, 2=CO, 3=NOx) giving
C              the relative effectiveness of a Test and Repair IM
C              program as compared to a Test Only program, originally
C              always was 0.5
C ETCFLG  I   Etc. flag, may be used for something in the future.
C EXCESS  R   See routines R1 and R2
C HACRDT  R   Array of annual Retest-hybrid credits read from the
C              Hybrid-retest input file
C HBCRDT  R   Array of biennial Retest-hybrid credits read from the 
C              Hybrid-retest input file
C HYBFLG  I   Hybrid program flag
C IBY     I   Counter for Benefit Years
C IMY     I   Counter for model year
C IMFLG   I   I/M flag:  1 if no RSD program modifications done on
C              IMDATA; 2 if data was changed
C IN1981  C   Character string name of the IMDATA.D type input filename
C IN198H  C   Character string name of the IMH.D type input filename
C IP      I   Counter for pollutants
C IREC    I   Counter for credit lines
C ISMART  I   Counter for digits in the Smart control strip
C ITECH   I   Counter for Tech type:  1, 2, and 4+
C NCREDT  R   Array of new credits
C NVSEEA  R   Fraction of vehicles seen by RSD, annual program
C NVSEEB  R   Fraction of vehicles seen by RSD, biennial program
C NUMBER  I   Total number of vehicles subject to the I/M program
C OLDFLG  I   If old data, OLDFLG=1, if new, 0.
C OPTION  I   Option--see RSDDRV
C OUT198  C   Char. string name of the RSDDATA.D type output filename
C RSDD    C   Char. string name of the input data file
C SCAN    I   Number of valid veh. measurements per month at RSD sites
C SMARK   I   Array holding the first four digits of a biennial Smart
C              line (the Smart control strip):  altitude 1=Low 2=High; 
C              frequency 1=annual 2=biennial; technology 1=TECH1&2
C              2=TECH4+; test type 1=Idle 2=2500/Idle 3=Loaded/Idle
C              4=IM240 Test
C SMART   I   Array holding the 1st four digits of an annual Smart line
C THREE   C   Character string name for the flags HYBFLG, IMFLG, and
C              ETCFLG if they exist, otherwise it contains part of the
C              comment line
C TIMES   I   Minimum number of times a vehicle must be scanned between
C              inspections to be eligible for targetting
C UEXCE4  R   RSD effectiveness for Tech type 4+
C VMT     I   Vehicle miles travelled by age
C
C
C Notes:  Tech 1 refers to pre-1975 vehicles, Tech 2 to those from
C         1975-1980, and Tech 4+ to those of 1981 and later.
C 10-July-1995 @ CSC-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 31-Jan-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C 19-Mar-1996 @ DynTel-wcs Request 2-498 RSD Credits for Tech 1 & 2
C
C -----------------
C DECLARE VARIABLES
C -----------------
C
      CHARACTER CRDCOM*19, IN1981*40, IN198H*40, OUT198*40, RSDD*40
      CHARACTER THREE*3
C
      INTEGER AGE, ETCFLG, HYBFLG, IBY, IMFLG, IP, IREC, ISMART
      INTEGER NUMBER, OLDFLG, OPTION, SCAN, SMARK(4), SMART(4), TIMES
      INTEGER VMT(25)
C
      REAL ACREDT(18,3,24), CCUTHC, CCUTCO, CCUTNO, CKUTHC, CKUTCO
      REAL CKUTNO, CUTS(3), EFF(3), EXCESS(3,15,3), HACRDT(24)
      REAL HBCRDT(24), NCREDT(24), NVSEEA(25), NVSEEB(25), UEXCE4(3)
C
      COMMON /OP1/AGE,CUTS,NUMBER,SCAN,TIMES,VMT,EXCESS,OPTION,EFF
C
C Initialize OLDFLG to 0, new data.
C
      OLDFLG=0
C
      WRITE(*,200)
 200  FORMAT(/,  ' Starting to alter 1981 and newer model ',
     &            'years vehicles I/M credits to include ',/,
     &           ' Remote Sensing Devices credits',/,
     &           ' ---------------------------------------',
     &            '------------------------------------- ')
C
C ----------
C OPEN FILES
C ----------
C
      OPEN(UNIT=2,FILE=IN1981,ERR=300,STATUS='OLD')
      OPEN(UNIT=4,FILE=IN198H,ERR=302,STATUS='OLD')
      OPEN(UNIT=3,FILE=OUT198,ERR=305)
C
C ------------------
C START PROCESS LOOP
C ------------------
C
 70   CONTINUE
C
C At this point, either processing has just started, and file IN1981
C (and file IN198H) have not been read yet, or
C annual data from file IN1981, annual data from file IN198H
C and biennial data from file IN198H have just been
C processed, and the code is about to search the next record below
C the last annual IN1981 data block in order to find the next
C annual IN1981 data block.
C
C Read the current Smart control strip, cut point values and 
C description line from file IN1981.  If the end of
C the file is arrived at, this means that no more credit blocks are
C available in IN1981 and processing will end
C without any warnings.  This means that the amount of information in
C sent to the output file will match the amount in IN1981.
C
 30   CONTINUE
C
      READ(2,100,END=20,ERR=310)(SMART(ISMART),ISMART=1,4),
     &                          CCUTHC,CCUTCO,CCUTNO,THREE
 100  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,A3)
C
      READ(THREE,102,ERR=22) HYBFLG,IMFLG,ETCFLG
 102  FORMAT(3I1)
C
      GO TO 23
C
 22   CONTINUE
C
C An error in reading flags from THREE means that they aren't there;
C thus IN1981 is old-type data
C
      OLDFLG=1
C
 23   CONTINUE
C
C Reading a Smart line -- looking for annual data in input file
C
      IF (SMART(2).NE.1) THEN
C
C Not annual; jump forward to the next Smart line and read it
C
        DO 25 IREC=1,54
          READ(2,105,END=20)
 105      FORMAT(1X)
 25     CONTINUE
C       
        GO TO 30
      END IF
C
C Execute the following if OLDFLG is not 1; the following is for new
C data.
C
      IF (OLDFLG.NE.1) THEN
C
C Halt processing if the annual Smart line found has a value
C of IMFLG that is not one, because this means that the annual
C data has already been changed due to RSD effects, and making more
C than one change on the same data would result in nonsense.
C
        IF ( (IMFLG.NE.1).AND.(IMFLG.EQ.0) ) THEN
          GO TO 315
        END IF
C
      END IF
C
C Found Test-only annual data -- reading annual credits from input file
C
C Read (and save in array ACREDT for later use) the annual credits.
C
      PRINT *,'Reading old test-only annual credits'
C
C Loop for the 18 model years stored in the record.
C
      DO 35 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 36 IP=1,3
C
C Read the 24 age credit values
C
          READ(2,110,END=320,ERR=325)(ACREDT(IMY,IP,IBY),IBY=1,24),
     &                               CRDCOM
 110      FORMAT(24F5.3,A19)
C
 36     CONTINUE
C
 35   CONTINUE
C
C Done reading in annual credits from input file
C
C Search for the corresponding annual Smart line in file IN198H
C
      REWIND(4)
C
 40   CONTINUE
C
C Hybrid data is not changed by this code, thus there is no reason to
C read in or change the flags.  Don't read into the flag area.
C
      READ(4,103,END=330,ERR=335)(SMARK(ISMART),ISMART=1,4),
     &                           CKUTHC,CKUTCO,CKUTNO
 103  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
C
C Reading a Smart line -- looking for annual data in input file
C
C Check to see if it is the matching annual Smart line.  If it is not, 
C jump ahead and read the next Smart line.  (Note that, since an annual
C Smart line is being searched for, and the SMART array contains annual
C information, it is appropriate to compare SMARK(2) to SMART(2), since
C these arrays are 1 for annual and 2 for biennial.)
C
      IF ( (SMARK(1).NE.SMART(1)) .OR. (SMARK(2).NE.SMART(2)) .OR.
     &     (SMARK(3).NE.SMART(3)) .OR. (SMARK(4).NE.SMART(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 45 IREC=1,54
          READ(4,105,END=330)
C105      FORMAT(1X)
 45     CONTINUE
C
        GO TO 40
      END IF
C
C Found matching Retest-hybrid annual Smart line -- reading annual
C credits from input file
C
C At this point, the matching annual Smart line has been found.
C Write the new annual Smart line to the output file.
C
C If old data, write out IMFLG as '2' and the others as blanks
C
      IF (OLDFLG.EQ.1) THEN
C
        WRITE(3,218,ERR=345)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 218    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      ELSE
C
C New data; write IMFLG as '2' and echo the others
C
        WRITE(3,220,ERR=345)(SMARK(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 220    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'annual credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      END IF
C
      PRINT *,'Reading retest-hybrid annual credits and writing new ',
     & 'annual credits'
C
C Write the new annual credits.
C
C Loop for the 18 model years stored in the record.
C
      DO 50 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 52 IP=1,3
C
C Read the 24 age credit values
C
          READ(4,110,END=350,ERR=355)(HACRDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT (24F5.3,A19)
C
C Calculate the new annual credit.
C
C Note:  new annual credit = Test-only annual credit * F * E +
C Hybrid-retest annual credit * (1-F*E).  The data from
C file IN1981 is Test-only credit.
C
          DO 54 IBY=1,24
C
            NCREDT(IBY) =
     & ACREDT(IMY,IP,IBY) * NVSEEA(IBY) * UEXCE4(IP) +
     & HACRDT(IBY) * ( 1.0 - NVSEEA(IBY) * UEXCE4(IP) )
C
 54       CONTINUE
C
          WRITE(3,110,ERR=360)(NCREDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT(24F5.3,A19)
C
 52     CONTINUE
C
 50   CONTINUE
C
C Go back to beginning of file IN198H to begin the
C search for the biennial Smart line corresponding to the above 
C annual Smart line
C
      REWIND(4)
C
C Read current Smart line
C
 60   CONTINUE
C
C Again, hybrid data is not changed by this code, thus there is no
C reason to read in or change the flags.  Don't read into the flag area.
C
      READ(4,103,END=365,ERR=370)(SMART(ISMART),ISMART=1,4),CCUTHC,
     &                           CCUTCO,CCUTNO
C103  FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1)
C
C Reading a Smart line -- looking for biennial data in input file
C
C Check to see if it is the matching biennial Smart line.  If it is not, 
C jump ahead and read the next Smart line.  (Note that SMART(2) is 1
C for annual and 2 for biennial.)
C
      IF ( (SMART(1).NE.SMARK(1)) .OR. (SMART(2).NE.2) .OR.
     &     (SMART(3).NE.SMARK(3)) .OR. (SMART(4).NE.SMARK(4)) .OR.
     &     (CCUTHC  .NE.  CKUTHC) .OR. (CCUTCO  .NE.  CKUTCO) .OR.
     &     (CCUTNO  .NE.  CKUTNO) ) THEN
C       
        DO 55 IREC=1,54
          READ(4,105,END=365)
C105      FORMAT(1X)
 55     CONTINUE
C
        GO TO 60
      END IF
C
C Found matching Retest-hybrid biennial Smart line -- reading biennial
C credits from input file
C
C At this point, the matching biennial Smart line has been found.
C Write the new biennial Smart line to the output file.
C
C If old data, write out IMFLG as '2' and the others as blanks
C
      IF (OLDFLG.EQ.1) THEN
C
        WRITE(3,234,ERR=380)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,OPTION,RSDD
 234    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,' 2 ',1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      ELSE
C
C New data; write out IMFLG as '2' and echo the others
C
        WRITE(3,235,ERR=380)(SMART(ISMART),ISMART=1,4),CCUTHC,CCUTCO,
     &                      CCUTNO,HYBFLG,ETCFLG,OPTION,RSDD
 235    FORMAT(4I1,1X,F5.1,1X,F4.1,1X,F5.1,1X,I1,'2',I1,1X,'New ',
     &         'biennial credits, Option = ',I1,', Program type = 3, ',
     &         'input data file ',A40)
      END IF
C
      PRINT *,'Reading retest-hybrid biennial credits and writing ',
     & 'new biennial credits'
C
C Write the new biennial credits.
C
C Loop for the 18 model years stored in the record.
C
      DO 65 IMY=1,18
C
C Loop for the 3 pollutants (HC, CO, and NOX) in the record.
C
        DO 67 IP=1,3
C
C Read the 24 age credit values
C
          READ(4,110,END=385,ERR=390)(HBCRDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT (24F5.3,A19)
C
C Calculate the new biennial credit.
C
C Note:  new biennial credit = Test-only annual credit * F * E +
C Hybrid-retest biennial credit * (1-F*E).  The data from
C file IN1981 is Test-only credit.
C
          DO 69 IBY=1,24
C
            NCREDT(IBY) =
     & ACREDT(IMY,IP,IBY) * NVSEEB(IBY) * UEXCE4(IP) +
     & HBCRDT(IBY) * ( 1.0 - NVSEEB(IBY) * UEXCE4(IP) )
C
 69       CONTINUE
C
          WRITE(3,110,ERR=395)(NCREDT(IBY),IBY=1,24),CRDCOM
C110      FORMAT(24F5.3,A19)
C
 67     CONTINUE
C
 65   CONTINUE
C
C Now go back up to the procedure for finding the next annual Smart
C line that has not been processed yet.
C
      GO TO 70
C
C --------------
C ERROR MESSAGES
C --------------
C
 300  CONTINUE
      WRITE(*,301)IN1981       
 301  FORMAT(/,  ' ERROR OPENING TEST-ONLY CREDITS INPUT ',
     &            'FILE ',A40)
      GO TO 75
C
 302  CONTINUE
      WRITE(*,303)IN198H       
 303  FORMAT(/,  ' ERROR OPENING RETEST-HYBRID CREDITS ',
     &            'INPUT FILE ',A40)
      GO TO 75
C
 305  CONTINUE
      WRITE(*,306)OUT198       
 306  FORMAT(/,  ' ERROR OPENING OUTPUT FILE ',A40)
      GO TO 75
C
 310  CONTINUE
      WRITE(*,311)IN1981       
 311  FORMAT(/,  ' ERROR READING SMART LINE FROM TEST-ONLY ',
     &            'CREDITS INPUT FILE ',A40)
      GO TO 75
C
 315  CONTINUE
      WRITE(*,316)IN1981       
 316  FORMAT(/,  ' ERROR ANNUAL DATA BLOCK HAS ALREADY BEEN ',
     &            'CHANGED IN TEST-ONLY CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 320  CONTINUE
      WRITE(*,321)IN1981       
 321  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM TEST-ONLY CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 325  CONTINUE
      WRITE(*,326)IN1981       
 326  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM ',
     &            'TEST-ONLY CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 330  CONTINUE
      WRITE(*,331)IN198H       
 331  FORMAT(/,  ' END OF FILE BEFORE MATCHING ANNUAL ',
     &            'SMART LINE WAS FOUND IN RETEST-HYBRID ',/,
     &           ' CREDITS INPUT FILE ',A40)
      GO TO 75
C
 335  CONTINUE
      WRITE(*,336)IN198H       
 336  FORMAT(/,  ' ERROR READING ANNUAL SMART LINE FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 345  CONTINUE
      WRITE(*,346)OUT198       
 346  FORMAT(/,  ' ERROR WRITING NEW ANNUAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
 350  CONTINUE
      WRITE(*,351)IN198H       
 351  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'ANNUAL CREDITS FROM RETEST-HYBRID CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 355  CONTINUE
      WRITE(*,356)IN198H       
 356  FORMAT(/,  ' ERROR READING ANNUAL CREDITS FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 360  CONTINUE
      WRITE(*,361)OUT198       
 361  FORMAT(/,  ' ERROR WRITING NEW ANNUAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
 365  CONTINUE
      WRITE(*,366)IN198H       
 366  FORMAT(/,  ' END OF FILE BEFORE MATCHING BIENNIAL ',
     &            'SMART LINE WAS FOUND IN RETEST-HYBRID ',/,
     &           ' CREDITS INPUT FILE ',A40)
      GO TO 75
C
 370  CONTINUE
      WRITE(*,371)IN198H       
 371  FORMAT(/,  ' ERROR READING BIENNIAL SMART LINE FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 380  CONTINUE
      WRITE(*,381)OUT198       
 381  FORMAT(/,  ' ERROR WRITING NEW BIENNIAL SMART LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
 385  CONTINUE
      WRITE(*,386)IN198H       
 386  FORMAT(/,  ' UNEXPECTED END OF FILE WHILE READING ',
     &            'BIENNIAL CREDITS FROM RETEST-HYBRID CREDITS ',/,
     &           ' INPUT FILE ',A40)
      GO TO 75
C
 390  CONTINUE
      WRITE(*,391)IN198H       
 391  FORMAT(/,  ' ERROR READING BIENNIAL CREDITS FROM ',
     &            'RETEST-HYBRID CREDITS INPUT FILE ',/,
     &           ' ',A40)
      GO TO 75
C
 395  CONTINUE
      WRITE(*,396)OUT198       
 396  FORMAT(/,  ' ERROR WRITING NEW BIENNIAL CREDIT LINE TO ',
     &            'OUTPUT FILE ',A40)
      GO TO 75
C
C --------------
C END PROCEDURES
C --------------
C
 75   CONTINUE
      WRITE(*,397)       
 397  FORMAT(/,  ' CONVERSION ENDED ABNORMALLY',/)
      GO TO 80
C
 20   CONTINUE
      WRITE(*,245)
 245  FORMAT(/,  ' Conversion ended normally',/)
C
 80   CONTINUE
C
      CLOSE (3)
      CLOSE (4)
      CLOSE (2)
C
      RETURN
      END
